<img src="https://github.com/user-attachments/assets/16d84f7d-dee7-40d9-9990-d0f31bd1b028" width="20%" style="float: right; margin-left: 10px;">

# Tortilla 

Hello! I'm a Tortilla, a format to serialize your EO data 🤗.

